-- author="Jeffrey Fielding"
-- version=1
-- File routines for Euphoria Pre-Processor
-- path = addSlash(path)
--  adds a \ to path if it needs one
-- path = absolutePath(path)
--  gets the absolute path of a path (\windows -> c:\windows)
-- path = absoluteName(path)
--  gets the absolute name of a file (\windows\win.ini -> c:\windows\win.ini)
-- path = getName(path)
--  gets the name of the file in path (\epp.ex -> epp.ex)
-- path = includeName(path)
--  gets the absolute name of an included file
--  (graphics.e -> c:\euphoria\include\graphics.e)
-- file_data = loadFile(path/file_number)
--  Loads a file into a sequence
include file.e      -- for use with includeName to see whether a file exists
		    -- also for current_dir()
include wildcard.e  -- to make the paths in lower case (so you can use compare)

global function addSlash(sequence s)
    if s[length(s)] != '\\' then
	return s & '\\'
    end if
    return s
end function
procedure cd(sequence p)
    if length(p) > 2 then
	if p[2] = ':' then -- If it contains a drive
	    system(p[1..2],2)
	end if
    end if
    system("cd " & p,2)
end procedure
global function absolutePath(sequence p)
    sequence curdir, ret
    curdir = current_dir()
    if length(p) = 0 then
	return addSlash(lower(curdir))
    end if
    cd(p)
    ret = current_dir()
    cd(curdir)
    return addSlash(lower(ret))
end function
function getName(sequence s)
    for i = length(s) to 1 by -1 do
	if s[i] = '\\' then
	    return s[i+1..length(s)]
	end if
    end for
    return s
end function
global function absoluteName(sequence s)
    sequence path, file
    file = s
    path = ""
    for i = length(s) to 1 by -1 do
	if s[i] = '\\' then
	    path = s[1..i]
	    file = s[i+1..length(s)]
	    exit
	end if
    end for
    return absolutePath(path) & lower(file)
end function
global function includeName(sequence s)
    if sequence(dir(s)) then
	return absoluteName(s) -- Found it in current directory
    else
	s = absolutePath(getenv("EUDIR")) & "include\\" & s
	if sequence(dir(s)) then
	    return s -- Found it in include directory
	end if
    end if
    return "" -- The file couldn't be found in the current directory
	      -- or in the include directory.
end function
global function loadFile(object x)
    sequence r
    integer t
    if sequence(x) then
	x = open(x,"r")
    end if
    if x = -1 then
	return -1
    end if
    r = {}
    t = getc(x)
    while t != -1 do
	r = r & t
	t = getc(x)
    end while
    close(x)
    return r
end function
